@@ -39,6 +39,8 @@ class Connection;
 class SlaveBasePrivate;
 
 /**
+ * @class KIO::SlaveBase slavebase.h <KIO/SlaveBase>
+ *
  * There are two classes that specifies the protocol between application (job)
  * and kioslave. SlaveInterface is the class to use on the application end,
  * SlaveBase is the one to use on the slave end.
@@ -49,7 +51,7 @@ class SlaveBasePrivate;
  *
  * Note that a kioslave doesn't have a Qt event loop. When idle, it's waiting for a command
  * on the socket that connects it to the application. So don't expect a kioslave to react
- * to DBus signals for instance. KIOSlaves are short-lived anyway, so any kind of watching
+ * to D-Bus signals for instance. KIOSlaves are short-lived anyway, so any kind of watching
  * or listening for notifications should be done elsewhere, for instance in a kded module
  * (see kio_desktop's desktopnotifier.cpp for an example).
  *
@@ -299,8 +301,7 @@ public:
      *                  The default is i18n("&No").
      * Note: for ContinueCancel, buttonYes is the continue button and buttonNo is unused.
      *       and for Information, none is used.
-     * @param dontAskAgain A checkbox is added with which further confirmation can be turned off.
-     *        If the checkbox was ticked @p dontAskAgain will be set to true, otherwise false.
+     * @param dontAskAgainName the name used to store result from 'Do not ask again' checkbox.
      * @return a button code, as defined in ButtonCode, or 0 on communication error.
      */
     int messageBox(const QString &text, MessageBoxType type,
@@ -354,10 +355,7 @@ public:
 
     /**
      * Set the host
-     * @param host
-     * @param port
-     * @param user
-     * @param pass
+     *
      * Called directly by createSlave, this is why there is no equivalent in
      * SlaveInterface, unlike the other methods.
      *
@@ -891,7 +889,7 @@ public:
      * Wait for an answer to our request, until we get @p expected1 or @p expected2
      * @return the result from readData, as well as the cmd in *pCmd if set, and the data in @p data
      */
-    int waitForAnswer(int expected1, int expected2, QByteArray &data, int *pCmd = 0);
+    int waitForAnswer(int expected1, int expected2, QByteArray &data, int *pCmd = nullptr);
 
     /**
      * Internal function to transmit meta data to the application.
